@@ -597,13 +597,14 @@ class DataTransform(forms.ModelForm):
         forms = super(self.__class__,self).as_p()
 
         if hasattr(self, 'nested_constants_form') and self.nested_constants_form is not None:
-            forms = '\n '.join([forms,self.nested_constants_form.as_p()])
+            forms = forms + '\n  -' + self.nested_constants_form.as_p()
         if hasattr(self, 'nested_hardware_outputs_form') and self.nested_hardware_outputs_form is not None:
-            forms = '\n '.join([forms,self.nested_hardware_outputs_form.as_p()])
+            forms = forms + '\n  -' + self.nested_hardware_outputs_form.as_p()
         if hasattr(self, 'nested_hardware_stats_form') and self.nested_hardware_stats_form is not None:
-            forms = '\n '.join([forms,self.nested_hardware_stats_form.as_p()])
+            forms = forms + '\n  -' + self.nested_hardware_stats_form.as_p()
         if hasattr(self, 'nested_data_transformer_form') and self.nested_data_transformer_form is not None:
-            forms = '\n       -'.join([forms,self.nested_data_transformer_form.as_p()])
+            print('netdatatransform with number elements: ' + str(len(self.nested_data_transformer_form)))
+            forms = forms + '\n       -' + ' '.join(form.as_p() for form in self.nested_data_transformer_form)
         return mark_safe(forms)
 
     class Meta:
@@ -663,14 +664,14 @@ class DataTransformRoot(forms.ModelForm):
         forms = super(self.__class__,self).as_p()
 
         if hasattr(self, 'nested_constants_form') and self.nested_constants_form is not None:
-            forms = '\n'.join([forms,self.nested_constants_form.as_p()])
+            forms = forms + '\n  -' + self.nested_constants_form.as_p()
         if hasattr(self, 'nested_hardware_outputs_form') and self.nested_hardware_outputs_form is not None:
-            forms = '\n'.join([forms,self.nested_hardware_outputs_form.as_p()])
+            forms = forms + '\n  -' + self.nested_hardware_outputs_form.as_p()
         if hasattr(self, 'nested_hardware_stats_form') and self.nested_hardware_stats_form is not None:
-            forms = '\n'.join([forms,self.nested_hardware_stats_form.as_p()])
+            forms = forms + '\n  -' + self.nested_hardware_stats_form.as_p()
         if hasattr(self, 'nested_data_transformer_form') and self.nested_data_transformer_form is not None:
             print('netdatatransform with number elements: ' + str(len(self.nested_data_transformer_form)))
-            forms = '\n       -'.join([forms,self.nested_data_transformer_form.as_p()])
+            forms = forms + '\n       -' +  ' '.join(form.as_p() for form in self.nested_data_transformer_form)
         return mark_safe(forms)
 
     class Meta:
